@@ -7,5 +7,5 @@ TAR=../mongo-java-driver_${VERSION}.orig.tar.xz
 
 tar -xf $3
 rm $3
-XZ_OPT=--best tar -c -v -J -f $TAR --exclude '*.jar' $DIR
+XZ_OPT=--best tar -c -v -J -f $TAR --exclude '*.jar' --exclude 'gradlew*' --exclude 'gradle/wrapper' $DIR
 rm -Rf $DIR
